@@ -6,8 +6,7 @@ print.geochronologic_list <- function(x, ...){
   dataset.id <- sapply(lapply(x, function(y)y[[1]]$dataset.meta), '[[', 'dataset.id')
   
   #  Get site locations:
-  locs <- do.call(rbind.data.frame,
-                  lapply(x, function(y)get_site(y[[1]])[,c('long', 'lat')]))
+  locs <- data.frame(get_site(x))[,c('long', 'lat')]
   
   ages <- sapply(x, function(y) nrow(y[[2]]))
   mins <- sapply(x, function(y) min(y[[2]]$age, na.rm = TRUE))
@@ -15,9 +14,13 @@ print.geochronologic_list <- function(x, ...){
   
   cat(paste0('A geochronology_list containing ', length(x), ' objects:\n',
            'Accessed from ', 
-           format(as.POSIXct(dates[1], origin=Sys.time()-as.numeric(Sys.time())), "%Y-%m-%d %H:%M"),
+           format(as.POSIXct(dates[1], 
+                             origin = Sys.time() - as.numeric(Sys.time())), 
+                  "%Y-%m-%d %H:%M"),
            'h to ',
-           format(as.POSIXct(dates[2], origin=Sys.time()-as.numeric(Sys.time())), "%Y-%m-%d %H:%M"),
+           format(as.POSIXct(dates[2], 
+                             origin = Sys.time() - as.numeric(Sys.time())), 
+                  "%Y-%m-%d %H:%M"),
            'h. \n',
            'Geochronologies:\n'))
   print(format(data.frame(id = dataset.id, 
